@@ -1,6 +1,8 @@
-package Parse::CPAN::Meta;
-
 use strict;
+package Parse::CPAN::Meta;
+# ABSTRACT: Parse META.yml and META.json CPAN metadata files
+our $VERSION = '1.4406'; # VERSION
+
 use Carp 'croak';
 
 # UTF Support?
@@ -17,7 +19,6 @@ BEGIN {
 	# Class structure
 	require 5.004;
 	require Exporter;
-	$Parse::CPAN::Meta::VERSION   = '1.4403';
 	@Parse::CPAN::Meta::ISA       = qw{ Exporter      };
 	@Parse::CPAN::Meta::EXPORT_OK = qw{ Load LoadFile };
 }
@@ -108,15 +109,17 @@ sub _can_load {
 # Create an object from a file
 sub LoadFile ($) {
   require CPAN::Meta::YAML;
-  return CPAN::Meta::YAML::LoadFile(shift)
+  my $object = CPAN::Meta::YAML::LoadFile(shift)
     or die CPAN::Meta::YAML->errstr;
+  return $object;
 }
 
 # Parse a document from a string.
 sub Load ($) {
   require CPAN::Meta::YAML;
-  return CPAN::Meta::YAML::Load(shift)
+  my $object = CPAN::Meta::YAML::Load(shift)
     or die CPAN::Meta::YAML->errstr;
+  return $object;
 }
 
 1;
@@ -125,10 +128,16 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Parse::CPAN::Meta - Parse META.yml and META.json CPAN metadata files
 
+=head1 VERSION
+
+version 1.4406
+
 =head1 SYNOPSIS
 
     #############################################
@@ -171,6 +180,8 @@ All error reporting is done with exceptions (die'ing).
 Note that META files are expected to be in UTF-8 encoding, only.  When
 converted string data, it must first be decoded from UTF-8.
 
+=for Pod::Coverage HAVE_UTF8 IO_LAYER
+
 =head1 METHODS
 
 =head2 load_file
@@ -248,29 +259,71 @@ old, an exception will be thrown.
 =head2 PERL_YAML_BACKEND
 
 By default, L<CPAN::Meta::YAML> will be used for deserializing YAML data. If
-the C<PERL_YAML_BACKEND> environment variable is defined, then it is intepreted
+the C<PERL_YAML_BACKEND> environment variable is defined, then it is interpreted
 as a module to use for deserialization.  The given module must be installed,
 must load correctly and must implement the C<Load()> function or an exception
 will be thrown.
 
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
 =head1 SUPPORT
 
-Bugs should be reported via the CPAN bug tracker at
+=head2 Bugs / Feature Requests
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Parse-CPAN-Meta>
+Please report any bugs or feature requests through the issue tracker
+at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Parse-CPAN-Meta>.
+You will be notified automatically of any progress on your issue.
 
-=head1 AUTHOR
+=head2 Source Code
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
 
-=head1 COPYRIGHT
+L<http://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta>
 
-Copyright 2006 - 2010 Adam Kennedy.
+  git clone git://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta.git
 
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
+=head1 AUTHORS
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+=over 4
+
+=item *
+
+Adam Kennedy <adamk@cpan.org>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Joshua ben Jore <jjore@cpan.org>
+
+=item *
+
+Neil Bowers <neil@bowers.com>
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
+
+=item *
+
+Steffen Mller <smueller@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Adam Kennedy and Contributors.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
